@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.090911';
+our $VERSION = '0.101014';
 
 use Acme::CPANAuthors::Register (
     AERDAN    => 'Kiyoshi Aman',
@@ -23,6 +23,7 @@ use Acme::CPANAuthors::Register (
     BASHI     => 'Toshimasa Ishibashi',
     BAYASHI   => 'Dai Okabayashi',
     BAYSIDE   => 'Jun Shimizu',
+    BOBPP     => 'Tadashi Matsuda',
     BOKUTIN   => 'Tomohiro Hosaka',
     BONAR     => 'Nakano Kyohei',
     BOXPHERE  => 'Satoshi Ohkubo',
@@ -30,6 +31,7 @@ use Acme::CPANAuthors::Register (
     CLAIRVY   => 'NAGAYA Shinichiro',
     COHTAN    => 'Kota Sakoda',
     DAIBA     => 'DAIBA, Keiichi',
+    DAMEO     => 'Takashi Higashigata',
     DANJOU    => 'Nobuo Danjou',
     DANKOGAI  => 'Dan Kogai',
     DGSCOPE   => 'Masayuki Komori',
@@ -47,6 +49,7 @@ use Acme::CPANAuthors::Register (
     HATA      => 'Masanori HATA',
     HAYASHI   => 'Hiroo HAYASHI',
     HEDWIG    => 'Yusuke Sugiyama',
+    HHORIUCHI => 'Hiroki Horiuchi',
     HIDE      => 'Hideo Kimura',
     HIGU      => 'Higuchi hiroyuki',
     HIKARINE  => 'Hajime Kurita',
@@ -71,6 +74,7 @@ use Acme::CPANAuthors::Register (
     INA       => 'INABA Hitoshi',
     ISHIGAKI  => 'Kenichi Ishigaki',
     ISOYA     => 'Ryohei Isoya',
+    ISSM      => 'IWATA, Susumu',
     ITWARRIOR => 'Hitoshi Amano',
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
@@ -87,6 +91,7 @@ use Acme::CPANAuthors::Register (
     KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
     KINSAN    => 'Hitoshi Yokozawa',
+    KITAMAKI  => 'ryo kitamaki',
     KMIYAZAKI => 'Keitaro Miyazaki',
     KNAGANO   => 'Keiichiro Nagano',
     KNOK      => 'NOKUBI Takatsugu',
@@ -101,10 +106,14 @@ use Acme::CPANAuthors::Register (
     KTAT      => 'Kato Atsushi',
     KUBOTA    => 'Tomohiro KUBOTA',
     KUMA      => 'KUMAGAI Kentaro',
+    KUNIYOSHI => 'Kuniyoshi Kouji',
     KURIHARA  => 'Yoshiki KURIHARA',
+    KURIYAMA  => 'Jun Kuriyama',
+    KUZUHA    => 'Kuzuha SHINODA',
     KWITKNR   => 'KAWAI, Takanori',
     KYANNY    => 'Kensuke Kaneko',
     KYO       => 'Kyo Nagashima',
+    KYOMAIODP => 'Kyoma Takahashi',
     KYORO     => 'Kyosuke INOUE',
     KZFM      => 'Kazufumi Ohkawa',
     KZTOMITA  => 'Kazuyoshi Tomita',
@@ -114,6 +123,7 @@ use Acme::CPANAuthors::Register (
     MAIDO     => 'Masahiro Funakoshi',
     MAKAMAKA  => 'Makamaka Hannyaharamitu',
     MAKOTO    => 'Shin Honda',
+    MAOE      => 'Mitsutoshi Aoe',
     MASAHITO  => 'Masahito Yoshida',
     MASAKI    => 'NAKAGAWA Masaki',
     MASANORIH => 'Masanori Hara',
@@ -130,8 +140,11 @@ use Acme::CPANAuthors::Register (
     MIYAMUKO  => 'MIYAMUKO Katsuyuki',
     MIYAZAKI  => 'Ittetsu Miyazaki',
     MIZZY     => 'Gosuke Miyashita',
+    MORIYA    => 'Moriya Masaki',
+    MURATA    => 'Shingo Murata',
     MYUJI     => 'Yuji Maeda',
     NABESHIMA => 'Masaaki NABESHIMA',
+    NAITO     => 'Naoyuki Ito',
     NANZOU    => 'Takaaki Mizuno',
     NAOKIURAI => 'Naoki URAI',
     NAOYA     => 'Naoya Ito',
@@ -140,7 +153,9 @@ use Acme::CPANAuthors::Register (
     NARUSE    => 'NARUSE, Yui',
     NEJIGANE  => 'Yu Nejigane',
     NEKOKAK   => 'Atsushi Kobayashi',
+    NEKOYA    => 'Ryo Miyake',
     NEZUMI    => 'IKEDA Soji',
+    NGS       => 'Atsushi NAGASE',
     NISHIGAYA => 'NISHIGAYA, Yuki',
     NISHIKAWA => 'Kazuhiro Nishikawa',
     NOZZZZZ   => 'Tetsunari Nozaki',
@@ -154,6 +169,8 @@ use Acme::CPANAuthors::Register (
     PAINA     => 'SATO Taisuke',
     PEN       => 'Abe Masahiro',
     PIA       => 'Michiya Honda',
+    POCKET    => 'Masato Sogame',
+    POPPEN    => 'Shinsuke Matsui',
     QUEEN     => 'Yasuhiro Miyazaki',
     RINTARO   => 'Rintaro Ishizaki',
     RIYWO     => 'Ryosuke IWANAGA',
@@ -176,9 +193,12 @@ use Acme::CPANAuthors::Register (
     SHIRAIWA  => 'Kazuma Shiraiwa',
     SHOT      => 'Shota Takayama',
     SKONNO    => 'Satoshi Konno',
+    SKUBOTA   => 'Satoshi KUBOTA',
     SNGJOKEN  => 'Shingo Kikugawa',
+    SONGMU    => 'Masayuki Matsuki',
     SUGMAK    => 'Makoto Sugiyama',
     SUZUKI    => 'Yuji Suzuki',
+    SYNCLOVER => 'Naoya Sato',
     TAIY      => 'Taisuke Yamada',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
@@ -204,19 +224,23 @@ use Acme::CPANAuthors::Register (
     TOKUHIROM => 'MATSUNO Tokuhiro',
     TOMITA    => 'Naoki Tomita',
     TOMYHERO  => 'Tomohiro Teranishi',
+    TONODERA  => 'Takahiro Onodera',
     TOONA     => 'Naoto Ishikawa',
     TOPIA     => 'Tatuya Noda',
     TORU      => 'Toru Hisai',
     TOSHIFJW  => 'Toshimitsu FUJIWARA',
     TRAVAIL   => 'Tomoyuki SAWA',
+    TSUCCHI   => 'Takuya Tsuchida',
     TSUKAMOTO => 'Makio Tsukamoto',
     TSUNODA   => 'TSUNODA Kazuya',
     TURUGINA  => 'KATOU Akira',
     TYANO     => 'Tatsuhiro YANO',
     TYPESTER  => 'Daisuke Murase',
     UMEMOTO   => 'Hajimu Umemoto',
+    USUALOMA  => 'Taku Amano',
     WATANABE  => 'WATANABE Hirofumi',
     WOREMACX  => 'Wore Macx',
+    XAICRON   => 'Yuji Shimada',
     XOR       => 'Izumi Kawashima',
     XCEZX     => 'Tsuyoshi Maekawa',
     YAMAMOTO  => 'Ryuzo Yamamoto',
@@ -226,18 +250,24 @@ use Acme::CPANAuthors::Register (
     YAPPO     => 'Kazuhiro Osawa',
     YASU      => 'Yasushi Saito',
     YASUHIRO  => 'Yasuhiro Onishi',
+    YIBE      => 'Yuki Ibe',
     YOSHIDA   => 'Hironori Yoshida',
+    YOSHIMI   => 'Keiji Yoshimi',
     YOSTY     => 'Koji Komatsu',
     YSAS      => 'Yasuhiro Sasama',
+    YSASAKI   => 'Yoshihiro Sasaki',
     YSUZUKI   => 'Yoshihiro SUZUKI',
     YTURTLE   => 'Satoshi Azuma',
     YUKI      => 'Yuki ANAI',
     YUKINOBU  => 'NAGAYASU Yukinobu',
     YUKIO     => 'Yukio Suzuki',
+    YOKKUNS   => 'Yohei Sato',
     YUPUG     => 'Yu Isobe',
     YUSUKE    => 'Yusuke Shibata',
     YUSUKEBE  => 'Yusuke Wada',
+    YUTA      => 'MASUDA Yuta',
     YUYAW     => 'Yuya Watanabe',
+    ZENTOOO   => 'Naosuke Yokoe',
     ZIGOROU   => 'Toru Yamaguchi',
     ZIGUZAGU  => 'Hiroshi Sakai',
 );
